schemetools.SchemePair
======================

.. abjad-lineage:: abjad.tools.schemetools.SchemePair.SchemePair

.. autoclass:: abjad.tools.schemetools.SchemePair.SchemePair

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.schemetools.SchemePair.SchemePair.force_quotes
      ~abjad.tools.schemetools.SchemePair.SchemePair.format_scheme_value
      ~abjad.tools.schemetools.SchemePair.SchemePair.__eq__
      ~abjad.tools.schemetools.SchemePair.SchemePair.__format__
      ~abjad.tools.schemetools.SchemePair.SchemePair.__ne__
      ~abjad.tools.schemetools.SchemePair.SchemePair.__repr__
      ~abjad.tools.schemetools.SchemePair.SchemePair.__str__

Bases
-----

- :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.schemetools.SchemePair.SchemePair.force_quotes
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.format_scheme_value
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.__eq__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.__format__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.__ne__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.__repr__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemePair.SchemePair.__str__
   :noindex:
